@@ -17,6 +17,7 @@ class ExecutionCreationAPIError(APIError):
             return
 
         if find_error(error_json.get('environment'), code='does_not_exist'):
-            yield 'Run `{}` to see the complete list of available environments.'.format(
-                click.style('vh environments', bold=True),
+            yield (
+                f'Run `{click.style("vh environments", bold=True)}` to see '
+                f'the complete list of available environments.'
             )
